import Assets from './assets';
import { getSkills } from './skills';
import type { Project } from '../types';

export const items: Array<Project> = [
	{
		slug: 'pathfinder',
		color: '#1684d6',
		description:
			'PathFinder est un jeu éducatif web et mobile basé sur la théorie des graphes, développé dans le cadre de mon projet à l\'IUT. Ce projet a été réalisé en groupe et vise à rendre l\'apprentissage des concepts de graphes ludique et accessible. Nous avons dû concevoir l\'application (C1), optimiser les performances (C2), et gérer les données des joueurs via une base de données SQL (C4). L\'application fonctionne en mode multijoueur local et prévoit une version en ligne avec des fonctionnalités supplémentaires comme un leaderboard. Nous avons également géré l\'infrastructure en Docker pour le déploiement (C3) et avons collaboré efficacement en équipe pour mener à bien ce projet (C5, C6).',
		shortDescription:
			'PathFinder est un jeu éducatif sur les graphes, conçu pour rendre l\'apprentissage des graphes ludique.',
		links: [],
		logo: Assets.PathFinder,
		name: 'PathFinder',
		period: {
			from: new Date(2024, 8, 1),
			to: new Date(2025, 3, 1)
		},
		skills: getSkills('js', 'php', 'html', 'css', 'csharp', 'kotlin', 'docker'),
		type: 'Application de gestion de tuteurs',
		screenshots: [
			{
				label: 'Page d\'accueil de l\'application mobile',
				src: 'https://media.discordapp.net/attachments/1357736232251031622/1357739136341246092/accueil-mobile.png?ex=67f14c9b&is=67effb1b&hm=b72e8fe659ec0daf8376b0c5e85ac2baa8905cb9bbf0cc824568da4045798bda&=&format=webp&quality=lossless&width=414&height=856'
			},
			{
				label: 'Page de jeu de l\'application mobile',
				src: 'https://media.discordapp.net/attachments/1357736232251031622/1357739135854448732/jeu-mobile.png?ex=67f14c9b&is=67effb1b&hm=47a873decbd2a5fd2c50f43b92cdbe09604f84702b5905b243cc0d7c3f1dfe9b&=&format=webp&quality=lossless&width=414&height=856'
			},
			{
				label: 'Page de jeu de l\'application web',
				src: 'https://media.discordapp.net/attachments/1357736232251031622/1357739135292407808/jeu-web.PNG?ex=67f14c9b&is=67effb1b&hm=80340c13f00f6f678fc02374a49e5419c728ef7e271c8d5031287be6f30bc676&=&format=webp&quality=lossless&width=1518&height=856'
			},
		],
		isPersonal: false
	},
	{
		slug: 'mimir',
		color: '#8d05c7',
		description:
			'Mimir est une application web et mobile de gestion de tuteurs faite dans le cadre d\'une SAÉ pour mon IUT. C\'est un travail de groupe que j\'ai dû faire avec l\'aide de deux de mes camarades. Nous avons dû réaliser un développement d\'application (C1) ainsi que son optimisation (C2). Afin de gérer les données des utilisateurs, il a été nécessaire de gérer des bases de données (C4) en SQL ainsi qu\'une API REST en C#. Nous avons aussi dû gérer des systèmes informatiques (C3) afin de déployer les applications en Docker. Finalement, comme dans tout projet à plusieurs, il a fallu apprendre à gérer un projet (C5) et collaborer afin que tout se déroule bien (C6).',
		shortDescription:
			'Mimir est une application de gestion de tuteurs faite dans le cadre d\'une SAÉ pour mon IUT.',
		links: [],
		logo: Assets.Mimir,
		name: 'Mimir',
		period: {
			from: new Date(2023, 9, 1),
			to: new Date(2024, 6, 1)
		},
		skills: getSkills('js', 'php', 'html', 'css', 'csharp', 'kotlin', 'docker'),
		type: 'Application de gestion de tuteurs',
		screenshots: [
			{
				label: 'Page d\'ajout d\'une séance',
				src: 'https://media.discordapp.net/attachments/1357736232251031622/1357736425650655262/ajout-seance.png?ex=67f14a15&is=67eff895&hm=8dd99c670f33966b3c3a39c657d509ce7a9975819d4b3d7f161d6c581314129d&=&format=webp&quality=lossless&width=1768&height=762'
			},
			{
				label: 'Page de gestion des comptes',
				src: 'https://media.discordapp.net/attachments/1357736232251031622/1357736426367750507/gestion-comptes.png?ex=67f14a15&is=67eff895&hm=a1edd859f5a5cd1d267f173e707ece949573d183769438f1bf57deddb1eef141&=&format=webp&quality=lossless&width=1521&height=856'
			},
			{
				label: 'Page de connexion à l\'application mobile',
				src: 'https://media.discordapp.net/attachments/1357736232251031622/1357736426048852080/app-connexion.png?ex=67f14a15&is=67eff895&hm=3bef4050e66369f099408a6fb28bc9f6f04ceb4a617a4daae034a888eb945f01&=&format=webp&quality=lossless&width=405&height=856'
			},
		],
		isPersonal: false
	},
	{
		slug: 'affinity',
		color: '#e21ace',
		description:
			'Affinity est une application mobile de rencontre sur Android et iOS. C\'est un projet personnel que je désire faire dans le but d\'améliorer mes compétences. L\'application en est encore au stade de la conception.',
		shortDescription:
			'Affinity est une application mobile de rencontre sur Android et iOS.',
		links: [],
		logo: Assets.Affinity,
		name: 'Affinity',
		period: {
			from: new Date(2024, 1, 1)
		},
		skills: getSkills('flutter', 'dart'),
		type: 'Application de rencontre',
		screenshots: [],
		isPersonal: true
	}
];

export const title = 'Projets';
